Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/usermode/usermode According to the pmap manpage wir...



details:   https://anonhg.NetBSD.org/src/rev/1b9728f49850
branches:  trunk
changeset: 772380:1b9728f49850
user:      reinoud <reinoud%NetBSD.org@localhost>
date:      Sun Jan 01 13:52:13 2012 +0000

description:
According to the pmap manpage wired pages should not track RWM, so map them RW

diffstat:

 sys/arch/usermode/usermode/pmap.c |  8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diffs (29 lines):

diff -r b6fa3f130d8a -r 1b9728f49850 sys/arch/usermode/usermode/pmap.c
--- a/sys/arch/usermode/usermode/pmap.c Sun Jan 01 01:19:20 2012 +0000
+++ b/sys/arch/usermode/usermode/pmap.c Sun Jan 01 13:52:13 2012 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: pmap.c,v 1.85 2011/12/30 19:30:59 jmcneill Exp $ */
+/* $NetBSD: pmap.c,v 1.86 2012/01/01 13:52:13 reinoud Exp $ */
 
 /*-
  * Copyright (c) 2011 Reinoud Zandijk <reinoud%NetBSD.org@localhost>
@@ -27,7 +27,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.85 2011/12/30 19:30:59 jmcneill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: pmap.c,v 1.86 2012/01/01 13:52:13 reinoud Exp $");
 
 #include "opt_memsize.h"
 #include "opt_kmempages.h"
@@ -686,8 +686,8 @@
                mmap_ppl = THUNK_PROT_NONE;
        }
 
-       /* unmanaged pages are special; they dont track r/m */
-       if (vflags & PV_UNMANAGED)
+       /* unmanaged or wired pages are special; they dont track r/m */
+       if (vflags & (PV_UNMANAGED | PV_WIRED))
                mmap_ppl = THUNK_PROT_READ | THUNK_PROT_WRITE;
 
        pv->pv_mmap_ppl = mmap_ppl;



Home | Main Index | Thread Index | Old Index